@@ -489,9 +489,9 @@ class DataTransformerForm(BaseInlineFormSet):
     def add_fields(self, form, index):
         super(DataTransformerForm, self).add_fields(form, index)
 
-        if form.instance.accessory is not None:
+        if hasattr(form.instance, 'accessory') and form.instance.accessory is not None:
             dataTransformerInlineFormset = inlineformset_factory(DataTransformer, DataTransformer,formset=self.__class__,
-                                                                 fk_name='parent', form=DataTransform, extra=1
+                                                                 fk_name='parent', form=DataTransform
                                                                  )
             form.nested_data_transformer_form = dataTransformerInlineFormset(
                 instance=form.instance,
