@@ -391,16 +391,15 @@ class AccessoryViewSet(viewsets.ModelViewSet):
         calibration_form = CalibrationForm(initial={'accessory': accessory})
 
         datatransformerset = inlineformset_factory(DataTransformer, DataTransformer,formset=DataTransformerForm,
-                                                   fk_name='parent',
-                                                   extra=1, form=DataTransform)
+                                                   fk_name='parent', form=DataTransform)
 
         if accessory.has_data_transformer:
             data_transformer = accessory.datatransformer
-            formset = datatransformerset(instance=data_transformer)
+            formset = datatransformerset(initial=[DataTransform(instance=data_transformer)])
         else:
             data_transformer = DataTransformer.objects.create(accessory=accessory)
             data_transformer.save()
-            formset = datatransformerset(instance=data_transformer)
+            formset = datatransformerset(initial=[DataTransform(instance=data_transformer)])
 
         if request.accepted_renderer.format == 'html':
             return Response(
